@@ -1729,14 +1729,12 @@ gnome_program_initv (GType type,
 	const char *ctmp;
 	const GnomeModuleInfo *libgnome_module;
 
-	if (!program_module_list)
-	    program_module_list = g_ptr_array_new ();
-	if (!program_modules) {
-	    program_modules = g_ptr_array_new ();
-	    /* keep array NULL terminated */
-	    g_ptr_array_add (program_modules, NULL);
-	}
-	    
+	program_module_list = g_ptr_array_new ();
+	program_modules = g_ptr_array_new ();
+
+	/* keep array NULL terminated */
+	g_ptr_array_add (program_modules, NULL);
+
 	/* Register the requested modules. */
 	gnome_program_module_register (module_info);
 
